package com.android.socialgaming.tt_client;

import android.annotation.TargetApi;
import android.app.ProgressDialog;
import android.content.Intent;
import android.content.pm.PackageManager;
import android.support.annotation.NonNull;
import android.support.design.widget.Snackbar;
import android.support.v7.app.AppCompatActivity;

import android.os.Build;
import android.os.Bundle;
import android.provider.ContactsContract;
import android.text.TextUtils;
import android.view.View;
import android.widget.Button;
import android.widget.EditText;
import android.widget.Toast;

import com.android.socialgaming.tt_client.util.Service;
import com.google.android.gms.tasks.OnCompleteListener;
import com.google.android.gms.tasks.Task;
import com.google.firebase.auth.AuthResult;
import com.google.firebase.auth.FirebaseAuth;

import static android.Manifest.permission.READ_CONTACTS;

/**
 * A login screen that offers login via email/password.
 */
public class LoginActivity extends AppCompatActivity implements View.OnClickListener {

    /**
     * Id to identity READ_CONTACTS permission request.
     */
    private static final int REQUEST_READ_CONTACTS = 0;
    // UI references.
    private EditText mEmailView;
    private EditText mPasswordView;
    private Button register;
    private Button login;
    private ProgressDialog progress;
    private FirebaseAuth firebase;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.login);

        mEmailView = (EditText) findViewById(R.id.mailView);
        mPasswordView = (EditText) findViewById(R.id.pwView);
        register = (Button) findViewById(R.id.register);
        login = (Button) findViewById(R.id.login);
        firebase = FirebaseAuth.getInstance();
        progress = new ProgressDialog(this);
        register.setOnClickListener(this);
        login.setOnClickListener(this);

    }


    public void registerUser(){
        String email = mEmailView.getText().toString().trim();
        String passwort = mPasswordView.getText().toString().trim();
        if(TextUtils.isEmpty(email)){
            Toast.makeText(this,"Please enter an email",Toast.LENGTH_SHORT).show();
            return;
        }

        if(TextUtils.isEmpty(passwort) || passwort.length() < 8){
            Toast.makeText(this,"Make sure to enter a password with more than 7 characters", Toast.LENGTH_SHORT).show();
            return;
        }

        progress.setMessage("Registering...");
        progress.show();

        firebase.createUserWithEmailAndPassword(email, passwort)
                .addOnCompleteListener(this, new OnCompleteListener<AuthResult>() {
                    @Override
                    public void onComplete(@NonNull Task<AuthResult> task) {
                        if(task.isSuccessful()){
                            progress.dismiss();
                            Toast.makeText(LoginActivity.this,"Registration successfully!", Toast.LENGTH_SHORT).show();
                        }else{
                            progress.dismiss();
                            Toast.makeText(LoginActivity.this, "Could not register", Toast.LENGTH_SHORT).show();
                        }
                    }
                });

    }

    public void loginUser(){
        String email = mEmailView.getText().toString().trim();
        String passwort = mPasswordView.getText().toString().trim();

        if(TextUtils.isEmpty(email)){
            Toast.makeText(this,"Please enter an email",Toast.LENGTH_SHORT).show();
            return;
        }

        if(TextUtils.isEmpty(passwort)){
            Toast.makeText(this,"Please enter a passwort", Toast.LENGTH_SHORT).show();
            return;
        }

        progress.setMessage("Logging in...");
        progress.show();

        firebase.signInWithEmailAndPassword(email, passwort)
                .addOnCompleteListener(this, new OnCompleteListener<AuthResult>() {
                    @Override
                    public void onComplete(@NonNull Task<AuthResult> task) {
                        if(task.isSuccessful()){
                            progress.dismiss();
                            finish();
                            startActivity(new Intent(getApplicationContext(), MenuActivity.class));
                        }else{
                            progress.dismiss();
                            Toast.makeText(LoginActivity.this, "Could not login. Make sure to register first", Toast.LENGTH_SHORT).show();
                        }
                    }
                });
    }

    public void onClick(View view){
        if(view == register){
            registerUser();
        }

        if(view == login){
            loginUser();
        }
    }


    private boolean mayRequestContacts() {
        if (Build.VERSION.SDK_INT < Build.VERSION_CODES.M) {
            return true;
        }
        if (checkSelfPermission(READ_CONTACTS) == PackageManager.PERMISSION_GRANTED) {
            return true;
        }
        if (shouldShowRequestPermissionRationale(READ_CONTACTS)) {
            Snackbar.make(mEmailView, R.string.permission_rationale, Snackbar.LENGTH_INDEFINITE)
                    .setAction(android.R.string.ok, new View.OnClickListener() {
                        @Override
                        @TargetApi(Build.VERSION_CODES.M)
                        public void onClick(View v) {
                            requestPermissions(new String[]{READ_CONTACTS}, REQUEST_READ_CONTACTS);
                        }
                    });
        } else {
            requestPermissions(new String[]{READ_CONTACTS}, REQUEST_READ_CONTACTS);
        }
        return false;
    }



    /**
     * Attempts to sign in or register the account specified by the login form.
     * If there are form errors (invalid email, missing fields, etc.), the
     * errors are presented and no actual login attempt is made.
     */
    private boolean isEmailValid(String email) {
        //TODO: Replace this with your own logic
        return email.contains("@");
    }

    private boolean isPasswordValid(String password) {
        //TODO: Replace this with your own logic
        return password.length() > 4;
    }

    /**
     * Shows the progress UI and hides the login form.
     */
    @TargetApi(Build.VERSION_CODES.HONEYCOMB_MR2)


    private interface ProfileQuery {
        String[] PROJECTION = {
                ContactsContract.CommonDataKinds.Email.ADDRESS,
                ContactsContract.CommonDataKinds.Email.IS_PRIMARY,
        };

        int ADDRESS = 0;
        int IS_PRIMARY = 1;
    }

    /**
     * Represents an asynchronous login/registration task used to authenticate
     * the user.
     */
}

